Refactoring of CcnxForwardingHelper
diff --git a/helper/ccnx-forwarding-helper.h b/helper/ccnx-forwarding-helper.h
index c40bc12..fe9f9d4 100644
--- a/helper/ccnx-forwarding-helper.h
+++ b/helper/ccnx-forwarding-helper.h
@@ -26,6 +26,7 @@
 #include "ns3/output-stream-wrapper.h"
 #include "ns3/ccnx.h"
 #include "ns3/ccnx-flooding-strategy.h"
+#include "ns3/ccnx-pit.h"
 
 namespace ns3 {
 
@@ -58,9 +59,9 @@
   ~CcnxForwardingHelper ();
 
   /*
    * \brief creates a specified ForwardingStrategy object and binds it to Ccnx
    */
-  void SetForwarding(Ptr<Ccnx> ccnx) const;
+  void SetForwarding(Ptr<Ccnx> ccnx, Ptr<CcnxPit> pit) const;
     
   /**
    * \brief prints the forwarding tables of all nodes at a particular time.
@@ -58,9 +59,9 @@
 
   /*
-   * \brief creates a specified ForwardingStrategy object and binds it to Ccnx
+   * \brief creates a specified ForwardingStrategy object and binds it to Pit
    */